# Contributing to treetojson

## Pull Requests

1. Pull Requests are always welcome.
2. Fork the repo and create your branch from `master`.
3. Follow PEP8 standards.
4. If you've added code that should be tested, add tests

## Issues

Use Github [issues](https://github.com/saadsahibjan/treetojson/issues) section in the original treetojson repository to report any issues regarding the source code or documentation.
